Package: maraca
Version: 1.1.0
Type: Package
Title: The Maraca Plot: Visualizing Hierarchical Composite Endpoints
License: Apache License (>= 2)
Authors@R: c(
    person(given = "Martin", family = "Karpefors",
           email = "martin.karpefors@astrazeneca.com", role = "aut",
	         comment = c(ORCID = "0000-0003-3136-9882")),
    person(given = "Samvel B.", family = "Gasparyan",
           email = "samvel.gasparyan@astrazeneca.com", role = "aut",
	         comment = c(ORCID = "0000-0002-4797-2208")),
    person(given = "Stefano", family = "Borini",
           email = "stefano.borini@astrazeneca.com", role = c("ctb")),
    person(given = "Kevin", family = "Anderson",
           email = "kevin.anderson1@astrazeneca.com", role = "aut",
	         comment = c(ORCID = "0000-0002-9446-7386")),
    person(given = "Monika", family = "Huhn",
           email = "monika.huhn@astrazeneca.com", role = c("aut", "cre"),
	         comment = c(ORCID = "0009-0000-7865-6008")))
Description: Supports visual interpretation of hierarchical composite
    endpoints (HCEs). HCEs are complex constructs used as primary endpoints in
    clinical trials, combining outcomes of different types into ordinal endpoints,
    in which each patient contributes the most clinically important event (one and
    only one) to the analysis. See Karpefors M et al. (2022)
    <doi:10.1177/17407745221134949>.
URL: https://github.com/AstraZeneca/maraca
BugReports: https://github.com/AstraZeneca/maraca/issues
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5), hce (>= 0.8.5), ggplot2 (>= 3.4.0)
Imports: dplyr (>= 1.0), tidyr (>= 1.2), checkmate (>= 2.1),
        patchwork(>= 1.0.0), lifecycle
RoxygenNote: 7.3.3
Suggests: knitr (>= 1.39), here (>= 1.0.1), lintr (>= 3.0.0), withr (>=
        2.5.0), testthat (>= 3.1), rmarkdown, gganimate, gifski
NeedsCompilation: no
VignetteBuilder: knitr
Packaged: 2025-11-20 14:43:58 UTC; hidden
Author: Martin Karpefors [aut] (ORCID: <https://orcid.org/0000-0003-3136-9882>),
  Samvel B. Gasparyan [aut] (ORCID:
    <https://orcid.org/0000-0002-4797-2208>),
  Stefano Borini [ctb],
  Kevin Anderson [aut] (ORCID: <https://orcid.org/0000-0002-9446-7386>),
  Monika Huhn [aut, cre] (ORCID: <https://orcid.org/0009-0000-7865-6008>)
Maintainer: Monika Huhn <monika.huhn@astrazeneca.com>
Repository: CRAN
Date/Publication: 2025-11-20 20:50:02 UTC
Built: R 4.6.0; ; 2026-04-29 21:30:28 UTC; unix
