# Generated by roxygen2: do not edit by hand

S3method(animate_plot,adhce)
S3method(animate_plot,default)
S3method(animate_plot,maraca)
S3method(component_plot,adhce)
S3method(component_plot,default)
S3method(component_plot,maraca)
S3method(cumulative_plot,adhce)
S3method(cumulative_plot,default)
S3method(cumulative_plot,maraca)
S3method(mosaic_plot,adhce)
S3method(mosaic_plot,default)
S3method(mosaic_plot,maraca)
S3method(plot,adhce)
S3method(plot,maraca)
S3method(print,maraca)
export(animate_plot)
export(component_plot)
export(cumulative_plot)
export(dustin)
export(dustin_plot)
export(maraca)
export(mosaic_plot)
export(plot_maraca)
export(validate_maraca_plot)
import(ggplot2)
import(hce)
